==> browser-csv-exporter-1.0.0.tgz: package/README-en_US.md <==
[简体中文](./README.md) | English
# CSV Exporter
CSV Exporter is a lib for exporting CSV file in browser.

## Install
```
npm install csv-exporter --save

import CSVExporter from 'csv-exporter';
new CSVExporter(options)
```
Or download this repo:

```
<script src="./csv-exporter.min.js"></script>
new CSVExporter(options)
```

## Options
- fileName: filename of csv，default: new Date()
- columns: columns of csv，default：[]
- data: data of csv，default：[]

### Supporting options format
```
{
  fileName: 'fileName',
  columns: [{
    title: 'Name',
    key: 'name'
  }, {
    title: 'Age',
    key: 'age'
  }],
  data: [{
    name: 'A',
    age: 23
  }, {
    name: 'B',
    age: 23
  }]
}
```

```
{
  fileName: 'fileName',
  columns: [{
    title: 'name',
  }, {
    title: 'age',
  }],
  data: [{
    name: 'A',
    age: 23
  }, {
    name: 'B',
    age: 23
  }]
}
```

```
{
  fileName: 'fileName',
  columns: [{
    title: 'Name',
    key: 'name',
    formatter(value, row) {
     return value + 10;
    }
  }, {
    title: 'Age',
    key: 'age'
  }],
  data: [{
    name: 'A',
    age: 23
  }, {
    name: 'B',
    age: 23
  }]
}
```

```
{
  fileName: 'fileName',
  columns: ['Name', 'Age'],
  data: [['A', 23], ['B', 23]]
}
```

```
{
  fileName: 'fileName',
  columns: [{
  	title: 'Name'
  },{
  	title: 'Age',
  	formatter(value, row) {
  	 return value + 10;
  	}
  }],
  data: [['A', 23], ['B', 23]]
}
```

```
{
  fileName: 'fileName',
  columns: ['Name', 'age'],
  data: [['A', 23], ['B', 23]]
}
```

## API
- getContent(): return s string of csv content
- export(): download data as a csv file in browser

## Example
example.html

## Compatibility
Theoretically compatible with all browsers that support Blob and IE9+.

==> browser-csv-exporter-1.0.1.tgz: package/README-en_US.md <==
[简体中文](./README.md) | English
# Browser CSV Exporter
Browser CSV Exporter is a lib for exporting CSV file in browser.

## Install
```
npm install browser-csv-exporter --save

import CSVExporter from 'browser-csv-exporter';
new CSVExporter(options)
```
Or download this repo:

```
<script src="./browser-csv-exporter.min.js"></script>
new CSVExporter(options)
```

## Options
- fileName: filename of csv，default: new Date()
- columns: columns of csv，default：[]
- data: data of csv，default：[]

### Supporting options format
```
{
  fileName: 'fileName',
  columns: [{
    title: 'Name',
    key: 'name'
  }, {
    title: 'Age',
    key: 'age'
  }],
  data: [{
    name: 'A',
    age: 23
  }, {
    name: 'B',
    age: 23
  }]
}
```

```
{
  fileName: 'fileName',
  columns: [{
    title: 'name',
  }, {
    title: 'age',
  }],
  data: [{
    name: 'A',
    age: 23
  }, {
    name: 'B',
    age: 23
  }]
}
```

```
{
  fileName: 'fileName',
  columns: [{
    title: 'Name',
    key: 'name',
    formatter(value, row) {
     return value + 10;
    }
  }, {
    title: 'Age',
    key: 'age'
  }],
  data: [{
    name: 'A',
    age: 23
  }, {
    name: 'B',
    age: 23
  }]
}
```

```
{
  fileName: 'fileName',
  columns: ['Name', 'Age'],
  data: [['A', 23], ['B', 23]]
}
```

```
{
  fileName: 'fileName',
  columns: [{
  	title: 'Name'
  },{
  	title: 'Age',
  	formatter(value, row) {
  	 return value + 10;
  	}
  }],
  data: [['A', 23], ['B', 23]]
}
```

```
{
  fileName: 'fileName',
  columns: ['Name', 'age'],
  data: [['A', 23], ['B', 23]]
}
```

## API
- getContent(): return s string of csv content
- export(): download data as a csv file in browser

## Example
example.html

## Compatibility
Theoretically compatible with all browsers that support Blob and IE9+.
